.. _changes:

=========
Changelog
=========

You can find the changelog on the ` GitHub Release page<https://github.com/bo4e/BO4E-python/releases>`_.

=============
Compatibility
=============

The table below shows the compatibility matrix of the last BO4E versions.
You can also download the compatibility matrix as CSV file `here <_static/tables/compatibility_matrix.csv>`_.

Legend:

+------+------------------------------------------------------+
|  🟢  | | Compatible                                         |
|      | | No changes in the data model                       |
+------+------------------------------------------------------+
|  🟡  | | Compatible                                         |
|      | | Only non-critical changes in the data model        |
|      | | e.g. added fields, changed doc strings             |
+------+------------------------------------------------------+
|  🔴  | | Incompatible                                       |
|      | | Critical changes in the data model                 |
|      | | e.g. removed fields, changed types                 |
+------+------------------------------------------------------+
|  ➕  | | Compatible                                         |
|      | | Data model was added in this version               |
+------+------------------------------------------------------+
|  ➖  | | Incompatible                                       |
|      | | Data model was removed in this version             |
+------+------------------------------------------------------+
| \-   | | Data model not existent in this version            |
|      | | was removed before or will be added in future      |
+------+------------------------------------------------------+

.. csv-table:: Compatibility matrix
   :file: _static/tables/compatibility_matrix.csv
   :header-rows: 1
